import lightning_app as L


class ComponentB(L.LightningFlow):
    def run(self):
        print("hello from component B")
